from django import forms
from django.contrib import admin

from bx_django_utils.admin_utils.filters import ExistingCountedListFilter
from bx_django_utils.translation import TranslationFieldAdmin, validate_unique_translations
from bx_django_utils_tests.test_app.admin_filters_demo import NotAllSimpleListFilterDemo
from bx_django_utils_tests.test_app.models import (
    ColorFieldTestModel,
    CreateOrUpdateTestModel,
    TranslatedModel,
    TranslatedSlugTestModel,
    ValidateLengthTranslations,
)


class NameListFilter(ExistingCountedListFilter):
    title = 'name'
    parameter_name = 'name'
    model_field_name = 'name'


class SlugListFilter(ExistingCountedListFilter):
    title = 'slug'
    parameter_name = 'slug'
    model_field_name = 'slug'


@admin.register(CreateOrUpdateTestModel)
class CreateOrUpdateTestModelAdmin(admin.ModelAdmin):
    list_display = ('human_create_dt', 'human_update_dt', 'name', 'slug')
    list_display_links = ('name', 'slug')
    readonly_fields = ('create_dt', 'update_dt')
    prepopulated_fields = {'slug': ('name',)}
    list_filter = (NotAllSimpleListFilterDemo, NameListFilter, SlugListFilter)


@admin.register(ColorFieldTestModel)
class ColorFieldTestModelAdmin(admin.ModelAdmin):
    list_display = ('required_color', 'optional_color')


@admin.register(TranslatedModel)
class TranslatedModelAdmin(TranslationFieldAdmin):
    list_display = ['translated', 'translated_multiline', 'not_translated']
    list_display_links = ['translated', 'translated_multiline']


class TranslatedSlugTestModelForm(forms.ModelForm):
    """
    Demonstrate the usage of validate_unique_translations()
    """

    def clean(self):
        cleaned_data = super().clean()

        validate_unique_translations(
            ModelClass=TranslatedSlugTestModel,
            instance=self.instance,
            field_name='translated',
            translated_value=cleaned_data.get('translated'),
        )

        return cleaned_data

    class Meta:
        model = TranslatedSlugTestModel
        exclude = ()


@admin.register(TranslatedSlugTestModel)
class TranslatedSlugTestModelAdmin(TranslationFieldAdmin):
    form = TranslatedSlugTestModelForm
    list_display = ['translated', 'translated_slug']


@admin.register(ValidateLengthTranslations)
class ValidateLengthTranslationsModelAdmin(TranslationFieldAdmin):
    list_display = ['translated', 'translated_slug']



# Generated by Django 4.1.8 on 2023-04-27 12:29

from django.db import migrations, models

import bx_django_utils.translation


class Migration(migrations.Migration):
    dependencies = [
        ("test_app", "0008_alter_connecteduniqueslugmodel1_translated_and_more"),
    ]

    operations = [
        migrations.CreateModel(
            name="ValidateLengthTranslations",
            fields=[
                (
                    "id",
                    models.AutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                (
                    "translated",
                    bx_django_utils.translation.TranslationField(
                        languages=(("de", "German"), ("en", "English")),
                        max_value_length=20,
                        min_value_length=3,
                    ),
                ),
                (
                    "translated_slug",
                    bx_django_utils.translation.TranslationSlugField(
                        additional_uniqueness=None,
                        blank=True,
                        languages=(("de", "German"), ("en", "English")),
                        max_value_length=20,
                        min_value_length=3,
                        unique=True,
                    ),
                ),
            ],
        ),
    ]



# Generated by Django 4.1.7 on 2023-03-20 09:12

from django.db import migrations, models

import bx_django_utils.translation


class Migration(migrations.Migration):
    dependencies = [
        ("test_app", "0005_rawtranslatedmodel_translatedslugtestmodel_and_more"),
    ]

    operations = [
        migrations.CreateModel(
            name="NonUniqueTranslatedSlugTestModel",
            fields=[
                (
                    "id",
                    models.AutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                (
                    "translated",
                    bx_django_utils.translation.TranslationField(
                        ("de-de", "en-us", "es"),
                    ),
                ),
                (
                    "translated_slug",
                    bx_django_utils.translation.TranslationSlugField(
                        ("de-de", "en-us", "es"), blank=True, unique=False
                    ),
                ),
            ],
        ),
    ]



# Generated by Django 4.1.8 on 2023-04-12 12:56

from django.db import migrations

import bx_django_utils.translation


class Migration(migrations.Migration):
    dependencies = [
        ("test_app", "0007_connecteduniqueslugmodel1_connecteduniqueslugmodel2"),
    ]

    operations = [
        migrations.AlterField(
            model_name="connecteduniqueslugmodel1",
            name="translated",
            field=bx_django_utils.translation.TranslationField(
                languages=(
                    ("de-de", "German"),
                    ("en-us", "US-English"),
                    ("es", "Spanish"),
                )
            ),
        ),
        migrations.AlterField(
            model_name="connecteduniqueslugmodel1",
            name="translated_slug",
            field=bx_django_utils.translation.TranslationSlugField(
                additional_uniqueness=(
                    {
                        "app_label": "test_app",
                        "field_name": "translated_slug",
                        "model_name": "ConnectedUniqueSlugModel2",
                    },
                ),
                blank=True,
                languages=(
                    ("de-de", "German"),
                    ("en-us", "US-English"),
                    ("es", "Spanish"),
                ),
                unique=True,
            ),
        ),
        migrations.AlterField(
            model_name="connecteduniqueslugmodel2",
            name="translated",
            field=bx_django_utils.translation.TranslationField(
                languages=(
                    ("de-de", "German"),
                    ("en-us", "US-English"),
                    ("es", "Spanish"),
                )
            ),
        ),
        migrations.AlterField(
            model_name="connecteduniqueslugmodel2",
            name="translated_slug",
            field=bx_django_utils.translation.TranslationSlugField(
                additional_uniqueness=(
                    {
                        "app_label": "test_app",
                        "field_name": "translated_slug",
                        "model_name": "ConnectedUniqueSlugModel1",
                    },
                ),
                blank=True,
                languages=(
                    ("de-de", "German"),
                    ("en-us", "US-English"),
                    ("es", "Spanish"),
                ),
                unique=True,
            ),
        ),
        migrations.AlterField(
            model_name="nonuniquetranslatedslugtestmodel",
            name="translated",
            field=bx_django_utils.translation.TranslationField(
                languages=(
                    ("de-de", "German"),
                    ("en-us", "US-English"),
                    ("es", "Spanish"),
                )
            ),
        ),
        migrations.AlterField(
            model_name="nonuniquetranslatedslugtestmodel",
            name="translated_slug",
            field=bx_django_utils.translation.TranslationSlugField(
                additional_uniqueness=None,
                blank=True,
                languages=(
                    ("de-de", "German"),
                    ("en-us", "US-English"),
                    ("es", "Spanish"),
                ),
                unique=False,
            ),
        ),
        migrations.AlterField(
            model_name="translatedmodel",
            name="translated",
            field=bx_django_utils.translation.TranslationField(
                languages=(("de-de", "de-de"), ("en-us", "en-us"), ("es", "es"))
            ),
        ),
        migrations.AlterField(
            model_name="translatedmodel",
            name="translated_multiline",
            field=bx_django_utils.translation.TranslationField(
                blank=True,
                languages=(
                    ("de-de", "German"),
                    ("en-us", "US-English"),
                    ("es", "Spanish"),
                ),
            ),
        ),
        migrations.AlterField(
            model_name="translatedslugtestmodel",
            name="translated",
            field=bx_django_utils.translation.TranslationField(
                languages=(
                    ("de-de", "German"),
                    ("en-us", "US-English"),
                    ("es", "Spanish"),
                )
            ),
        ),
        migrations.AlterField(
            model_name="translatedslugtestmodel",
            name="translated_slug",
            field=bx_django_utils.translation.TranslationSlugField(
                additional_uniqueness=None,
                blank=True,
                languages=(("de-de", "de-de"), ("en-us", "en-us"), ("es", "es")),
                unique=True,
            ),
        ),
    ]



# Generated by Django 4.1.7 on 2023-03-22 11:31

from django.db import migrations, models

import bx_django_utils.translation


class Migration(migrations.Migration):
    dependencies = [
        ("test_app", "0006_nonuniquetranslatedslugtestmodel"),
    ]

    operations = [
        migrations.CreateModel(
            name="ConnectedUniqueSlugModel1",
            fields=[
                (
                    "id",
                    models.AutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                (
                    "translated",
                    bx_django_utils.translation.TranslationField(("de-de", "en-us", "es")),
                ),
                (
                    "translated_slug",
                    bx_django_utils.translation.TranslationSlugField(
                        ("de-de", "en-us", "es"),
                        additional_uniqueness=(
                            {
                                "app_label": "test_app",
                                "field_name": "translated_slug",
                                "model_name": "ConnectedUniqueSlugModel2",
                            },
                        ),
                        blank=True,
                        unique=True,
                    ),
                ),
            ],
        ),
        migrations.CreateModel(
            name="ConnectedUniqueSlugModel2",
            fields=[
                (
                    "id",
                    models.AutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                (
                    "translated",
                    bx_django_utils.translation.TranslationField(("de-de", "en-us", "es")),
                ),
                (
                    "translated_slug",
                    bx_django_utils.translation.TranslationSlugField(
                        ("de-de", "en-us", "es"),
                        additional_uniqueness=(
                            {
                                "app_label": "test_app",
                                "field_name": "translated_slug",
                                "model_name": "ConnectedUniqueSlugModel1",
                            },
                        ),
                        blank=True,
                        unique=True,
                    ),
                ),
            ],
        ),
    ]
